@@ -29,19 +29,19 @@ class Cylinder:
         return self._diameter
 
     def x(self):
-        if self._axis is 'x':
+        if self._axis == 'x':
             return self.height()
         else:
             return self.diameter()
 
     def y(self):
-        if self._axis is 'y':
+        if self._axis == 'y':
             return self.height()
         else:
             return self.diameter()
 
     def z(self):
-        if self._axis is 'z':
+        if self._axis == 'z':
             return self.height()
         else:
             return self.diameter()
@@ -96,19 +96,19 @@ class Block:
         return self._dims[0] * self._dims[1] * self._dims[2]
 
     def cross_section_area(self, axis: str):
-        if axis is 'x':
+        if axis == 'x':
             return self.y() * self.z()
-        elif axis is 'y':
+        elif axis == 'y':
             return self.x() * self.z()
-        elif axis is 'z':
+        elif axis == 'z':
             return self.x() * self.y()
 
     def inertia(self, axis: str):
-        if axis is 'x':
+        if axis == 'x':
             return (self.x() * self.y()**3)/12.0
-        elif axis is 'y':
+        elif axis == 'y':
             return (self.y() * self.x()**3)/12.0
-        elif axis is 'z':
+        elif axis == 'z':
             return 0.0 * ureg.m**4
 
     # Log the current value in the cli
